==> jc-1.4.0.tar.gz: javax/naming/directory/ModificationItem.h <==
// public class javax.naming.directory.ModificationItem

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class d863362949ef9df7 javax_naming_directory_ModificationItem

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_naming_directory_ModificationItem_H_
#define _JC_javax_naming_directory_ModificationItem_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_javax_naming_directory_Attribute$object;

// Typedefs
typedef struct _jc_javax_naming_directory_ModificationItem$sub_refs	_jc_javax_naming_directory_ModificationItem$sub_refs;
typedef struct _jc_javax_naming_directory_ModificationItem$sub_nonrefs	_jc_javax_naming_directory_ModificationItem$sub_nonrefs;
typedef struct _jc_javax_naming_directory_ModificationItem$refs	_jc_javax_naming_directory_ModificationItem$refs;
typedef struct _jc_javax_naming_directory_ModificationItem$nonrefs	_jc_javax_naming_directory_ModificationItem$nonrefs;
typedef struct _jc_javax_naming_directory_ModificationItem$object	_jc_javax_naming_directory_ModificationItem$object;

typedef const struct _jc_javax_naming_directory_ModificationItem$vmethods	_jc_javax_naming_directory_ModificationItem$vmethods;
typedef const struct _jc_javax_naming_directory_ModificationItem$vtable	_jc_javax_naming_directory_ModificationItem$vtable;
typedef const struct _jc_javax_naming_directory_ModificationItem$vtype	_jc_javax_naming_directory_ModificationItem$vtype;

// Constructors
extern void _jc_javax_naming_directory_ModificationItem$method$_init$a12538ba5eb629af(_jc_env *, struct _jc_javax_naming_directory_ModificationItem$object *, jint, struct _jc_object *);

// Virtual methods
extern struct _jc_object *_jc_javax_naming_directory_ModificationItem$method$getAttribute$16889fb774f07d79(_jc_env *, struct _jc_javax_naming_directory_ModificationItem$object *);
extern jint _jc_javax_naming_directory_ModificationItem$method$getModificationOp$e241d82359c1bea8(_jc_env *, struct _jc_javax_naming_directory_ModificationItem$object *);
extern struct _jc_java_lang_String$object *_jc_javax_naming_directory_ModificationItem$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_javax_naming_directory_ModificationItem$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_naming_directory_ModificationItem$method_info$getAttribute$16889fb774f07d79;
extern _jc_method _jc_javax_naming_directory_ModificationItem$method_info$getModificationOp$e241d82359c1bea8;
extern _jc_method _jc_javax_naming_directory_ModificationItem$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_javax_naming_directory_ModificationItem$vmethods {
	struct _jc_object	*(*getAttribute$16889fb774f07d79)(_jc_env *, struct _jc_javax_naming_directory_ModificationItem$object *);
	jint	(*getModificationOp$e241d82359c1bea8)(_jc_env *, struct _jc_javax_naming_directory_ModificationItem$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_javax_naming_directory_ModificationItem$object *);
};

// Vtable
struct _jc_javax_naming_directory_ModificationItem$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_naming_directory_ModificationItem$vmethods	javax_naming_directory_ModificationItem;
};

// Vtype
struct _jc_javax_naming_directory_ModificationItem$vtype {
	_jc_type			type;
	_jc_javax_naming_directory_ModificationItem$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_naming_directory_ModificationItem$sub_refs {
	struct _jc_object	*attr;
};

// Reference instance fields (object)
struct _jc_javax_naming_directory_ModificationItem$refs {
    _jc_javax_naming_directory_ModificationItem$sub_refs	javax_naming_directory_ModificationItem;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_naming_directory_ModificationItem$sub_nonrefs {
	jint	mod__5fop;
};

// Non-reference instance fields (object)
struct _jc_javax_naming_directory_ModificationItem$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_naming_directory_ModificationItem$sub_nonrefs	javax_naming_directory_ModificationItem;
};

// Object instance structure
struct _jc_javax_naming_directory_ModificationItem$object {
	_jc_javax_naming_directory_ModificationItem$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_naming_directory_ModificationItem$vtype	*vtype;
	_jc_javax_naming_directory_ModificationItem$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_naming_directory_ModificationItem$vtype _jc_javax_naming_directory_ModificationItem$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_naming_directory_ModificationItem, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_naming_directory_ModificationItem$class_object;

#endif	/* _JC_javax_naming_directory_ModificationItem_H_ */

==> jc-1.4.6.tar.gz: javax/naming/directory/ModificationItem.h <==
// public class javax.naming.directory.ModificationItem

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class d863362949ef9df7 javax_naming_directory_ModificationItem

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_naming_directory_ModificationItem_H_
#define _JC_javax_naming_directory_ModificationItem_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_javax_naming_directory_Attribute$object;

// Typedefs
typedef struct _jc_javax_naming_directory_ModificationItem$sub_refs	_jc_javax_naming_directory_ModificationItem$sub_refs;
typedef struct _jc_javax_naming_directory_ModificationItem$sub_nonrefs	_jc_javax_naming_directory_ModificationItem$sub_nonrefs;
typedef struct _jc_javax_naming_directory_ModificationItem$refs	_jc_javax_naming_directory_ModificationItem$refs;
typedef struct _jc_javax_naming_directory_ModificationItem$nonrefs	_jc_javax_naming_directory_ModificationItem$nonrefs;
typedef struct _jc_javax_naming_directory_ModificationItem$object	_jc_javax_naming_directory_ModificationItem$object;

typedef const struct _jc_javax_naming_directory_ModificationItem$vmethods	_jc_javax_naming_directory_ModificationItem$vmethods;
typedef const struct _jc_javax_naming_directory_ModificationItem$vtable	_jc_javax_naming_directory_ModificationItem$vtable;
typedef const struct _jc_javax_naming_directory_ModificationItem$vtype	_jc_javax_naming_directory_ModificationItem$vtype;

// Constructors
extern void _jc_javax_naming_directory_ModificationItem$method$_init$a12538ba5eb629af(_jc_env *, struct _jc_javax_naming_directory_ModificationItem$object *, jint, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_object *_jc_javax_naming_directory_ModificationItem$method$getAttribute$16889fb774f07d79(_jc_env *, struct _jc_javax_naming_directory_ModificationItem$object *) _JC_JCNI_ATTR;
extern jint _jc_javax_naming_directory_ModificationItem$method$getModificationOp$e241d82359c1bea8(_jc_env *, struct _jc_javax_naming_directory_ModificationItem$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_javax_naming_directory_ModificationItem$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_javax_naming_directory_ModificationItem$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_naming_directory_ModificationItem$method_info$getAttribute$16889fb774f07d79;
extern _jc_method _jc_javax_naming_directory_ModificationItem$method_info$getModificationOp$e241d82359c1bea8;
extern _jc_method _jc_javax_naming_directory_ModificationItem$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_javax_naming_directory_ModificationItem$vmethods {
	struct _jc_object	*(*getAttribute$16889fb774f07d79)(_jc_env *, struct _jc_javax_naming_directory_ModificationItem$object *) _JC_JCNI_ATTR;
	jint	(*getModificationOp$e241d82359c1bea8)(_jc_env *, struct _jc_javax_naming_directory_ModificationItem$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_javax_naming_directory_ModificationItem$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_naming_directory_ModificationItem$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_naming_directory_ModificationItem$vmethods	javax_naming_directory_ModificationItem;
};

// Vtype
struct _jc_javax_naming_directory_ModificationItem$vtype {
	_jc_type			type;
	_jc_javax_naming_directory_ModificationItem$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_naming_directory_ModificationItem$sub_refs {
	struct _jc_object	*attr;
};

// Reference instance fields (object)
struct _jc_javax_naming_directory_ModificationItem$refs {
    _jc_javax_naming_directory_ModificationItem$sub_refs	javax_naming_directory_ModificationItem;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_naming_directory_ModificationItem$sub_nonrefs {
	jint	mod__5fop;
};

// Non-reference instance fields (object)
struct _jc_javax_naming_directory_ModificationItem$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_naming_directory_ModificationItem$sub_nonrefs	javax_naming_directory_ModificationItem;
};

// Object instance structure
struct _jc_javax_naming_directory_ModificationItem$object {
	_jc_javax_naming_directory_ModificationItem$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_naming_directory_ModificationItem$vtype	*vtype;
	_jc_javax_naming_directory_ModificationItem$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_naming_directory_ModificationItem$vtype _jc_javax_naming_directory_ModificationItem$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_naming_directory_ModificationItem, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_naming_directory_ModificationItem$class_object;

#endif	/* _JC_javax_naming_directory_ModificationItem_H_ */
